@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -85,11 +85,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie - Tooling/wrappers for Oozie job deployment and scheduling
+App::Oozie
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -101,6 +105,10 @@ Oozie Workflow jobs are Directed Acyclical Graphs (DAGs) of actions.
 The sets of tools in this package tries to make it easier to generate,
 deploy and schedule Oozie application specs and files.
 
+=head1 NAME
+
+App::Oozie - Tooling/wrappers for Oozie job deployment and scheduling
+
 =head1 Methods
 
 =head2 debug
@@ -114,5 +122,25 @@ L<https://oozie.apache.org>.
 L<App::Oozie::Deploy>, L<App::Oozie::Run>, L<App::Oozie::Update::Coordinator>,
 L<http://oozie.apache.org>.
 
-=cut
+=head1 AUTHORS
 
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
