@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use parent qw( Exporter );
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use constant OOZIE_STATES_RERUNNABLE => qw(
     KILLED
@@ -154,11 +154,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Constants - Internal constants.
+App::Oozie::Constants
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -169,6 +173,10 @@ App::Oozie::Constants - Internal constants.
 
 Internal constants.
 
+=head1 NAME
+
+App::Oozie::Constants - Internal constants.
+
 =head1 Constants
 
 =head2 DATE_PATTERN
@@ -219,4 +227,25 @@ Internal constants.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
