@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw( App::Oozie::Forked::Template::ttree );
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 sub new {
     my($class, $log_collector, @pass_through) = @_;
@@ -43,3 +43,38 @@ sub emit_log {
 1;
 
 __END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+App::Oozie::Deploy::Template::ttree
+
+=head1 VERSION
+
+version 0.015
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
