@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -309,11 +309,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Deploy::Validate::DAG::Workflow - Part of the Oozie workflow DAG validator.
+App::Oozie::Deploy::Validate::DAG::Workflow
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -322,6 +326,10 @@ App::Oozie::Deploy::Validate::DAG::Workflow - Part of the Oozie workflow DAG val
 Used by Oozie deploy tool to prevent mistakes before submission. 
 Checks the workflow is a properly formed DAG.
 
+=head1 NAME
+
+App::Oozie::Deploy::Validate::DAG::Workflow - Part of the Oozie workflow DAG validator.
+
 =head1 Methods
 
 =head2 assert
@@ -374,9 +382,29 @@ Checks the workflow is a properly formed DAG.
         print $d3->force_directed_graph;
     }
 
-
 =head1 SEE ALSO
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
