@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -323,11 +323,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Deploy::Validate::Spec - Part of the Oozie Workflow validator kit.
+App::Oozie::Deploy::Validate::Spec
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -337,6 +341,10 @@ TBD
 
 TBD
 
+=head1 NAME
+
+App::Oozie::Deploy::Validate::Spec - Part of the Oozie Workflow validator kit.
+
 =head1 Methods
 
 =head2 local_path
@@ -361,4 +369,25 @@ TBD
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
