@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -357,13 +357,15 @@ __END__
 
 =pod
 
-=encoding utf8
-
-=for Pod::Coverage BUILD
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Rerun - The program to re-run Oozie workflows.
+App::Oozie::Rerun
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -374,6 +376,12 @@ App::Oozie::Rerun - The program to re-run Oozie workflows.
 
 This is an action/program in the Oozie Tooling.
 
+=for Pod::Coverage BUILD
+
+=head1 NAME
+
+App::Oozie::Rerun - The program to re-run Oozie workflows.
+
 =head1 Methods
 
 =head2 collect
@@ -410,4 +418,25 @@ This is an action/program in the Oozie Tooling.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
