@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -53,11 +53,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Role::Info - Helper to gather information about the tooling.
+App::Oozie::Role::Info
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -74,6 +78,10 @@ App::Oozie::Role::Info - Helper to gather information about the tooling.
 
 Helper to gather information about the tooling.
 
+=head1 NAME
+
+App::Oozie::Role::Info - Helper to gather information about the tooling.
+
 =head1 Methods
 
 =head2 log_versions
@@ -82,4 +90,25 @@ Helper to gather information about the tooling.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
