@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -47,11 +47,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Role::NameNode - Hadoop NameNode related accessors.
+App::Oozie::Role::NameNode
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -64,6 +68,10 @@ App::Oozie::Role::NameNode - Hadoop NameNode related accessors.
 This is a Role to be consumed by Oozie tooling classes and
 defines various fields.
 
+=head1 NAME
+
+App::Oozie::Role::NameNode - Hadoop NameNode related accessors.
+
 =head1 Accessors
 
 =head2 Overridable from cli
@@ -80,5 +88,25 @@ defines various fields.
 
 L<App::Oozie>.
 
-=cut
+=head1 AUTHORS
 
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
