@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -95,11 +95,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Role::Validate::XML - Internal role for validators.
+App::Oozie::Role::Validate::XML
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -110,6 +114,10 @@ App::Oozie::Role::Validate::XML - Internal role for validators.
 
 This is a Role to be consumed by Oozie validators.
 
+=head1 NAME
+
+App::Oozie::Role::Validate::XML - Internal role for validators.
+
 =head1 Methods
 
 =head2 validate_xml_property
@@ -118,4 +126,25 @@ This is a Role to be consumed by Oozie validators.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
