@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -1011,11 +1011,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Run - Schedule Oozie Coordinators and Workflows.
+App::Oozie::Run
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -1040,6 +1044,10 @@ For this to work, the coordinator.xml and workflow.xml must make
         </action>
     </coordinator-app>
 
+=head1 NAME
+
+App::Oozie::Run - Schedule Oozie Coordinators and Workflows.
+
 =head1 Methods
 
 =head3 ask
@@ -1106,4 +1114,25 @@ For this to work, the coordinator.xml and workflow.xml must make
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
