@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use YAML::XS ();
 use Moo;
@@ -27,11 +27,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Serializer::YAML - YAML encoder/decoder.
+App::Oozie::Serializer::YAML
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -46,6 +50,10 @@ App::Oozie::Serializer::YAML - YAML encoder/decoder.
 
 YAML encoder/decoder.
 
+=head1 NAME
+
+App::Oozie::Serializer::YAML - YAML encoder/decoder.
+
 =head1 Methods
 
 =head2 encode
@@ -56,4 +64,25 @@ YAML encoder/decoder.
 
 L<App::Oozie>. L<App::Oozie::Serializer>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
