@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use App::Oozie::Constants qw(
     RE_OOZIE_ID
@@ -107,11 +107,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Types::Common - Internal types.
+App::Oozie::Types::Common
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -121,6 +125,10 @@ App::Oozie::Types::Common - Internal types.
 
 Internal types.
 
+=head1 NAME
+
+App::Oozie::Types::Common - Internal types.
+
 =head1 Types
 
 =head2 IsBUNDLEID
@@ -145,4 +153,25 @@ Internal types.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
