@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use Type::Library -base;
 use Type::Utils -all;
@@ -32,11 +32,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Types::States - Internal types.
+App::Oozie::Types::States
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -46,6 +50,10 @@ App::Oozie::Types::States - Internal types.
 
 Internal types.
 
+=head1 NAME
+
+App::Oozie::Types::States - Internal types.
+
 =head1 Types
 
 =head2 IsOozieStateRerunnable
@@ -60,4 +68,25 @@ Internal types.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
