@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -520,11 +520,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Update::Coordinator - Updates the running coordinator.
+App::Oozie::Update::Coordinator
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -535,6 +539,10 @@ App::Oozie::Update::Coordinator - Updates the running coordinator.
 
 This is an action/program in the Oozie Tooling.
 
+=head1 NAME
+
+App::Oozie::Update::Coordinator - Updates the running coordinator.
+
 =head1 Methods
 
 =head2 run
@@ -561,4 +569,25 @@ This is an action/program in the Oozie Tooling.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
