@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use App::Oozie::Util::Plugin qw(
     find_files_in_inc
@@ -29,11 +29,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Util::Log4perl - Helper for handling the Log4perl template.
+App::Oozie::Util::Log4perl
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -44,6 +48,10 @@ App::Oozie::Util::Log4perl - Helper for handling the Log4perl template.
 
 Internal module.
 
+=head1 NAME
+
+App::Oozie::Util::Log4perl - Helper for handling the Log4perl template.
+
 =head1 Methods
 
 =head2 find_template
@@ -52,4 +60,25 @@ Internal module.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
