@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use parent qw( Exporter );
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our @EXPORT_OK = qw(
     remove_newline
@@ -44,11 +44,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Util::Misc - Miscellaneous utility functions
+App::Oozie::Util::Misc
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -58,6 +62,10 @@ App::Oozie::Util::Misc - Miscellaneous utility functions
 
 Internal module.
 
+=head1 NAME
+
+App::Oozie::Util::Misc - Miscellaneous utility functions
+
 =head1 Methods
 
 =head2 remove_newline
@@ -70,4 +78,25 @@ Internal module.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
