@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use parent qw( Exporter );
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use File::Spec::Functions qw(
     catdir
@@ -85,11 +85,15 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::Util::Plugin; - Utility for polugin handling.
+App::Oozie::Util::Plugin
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -103,6 +107,10 @@ App::Oozie::Util::Plugin; - Utility for polugin handling.
 
 Internal utility.
 
+=head1 NAME
+
+App::Oozie::Util::Plugin; - Utility for polugin handling.
+
 =head1 Methods
 
 =head2 find_files_in_inc
@@ -115,4 +123,25 @@ Internal utility.
 
 L<App::Oozie>.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
