@@ -4,7 +4,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
@@ -464,13 +464,15 @@ __END__
 
 =pod
 
-=encoding utf8
-
-=for Pod::Coverage BUILD
+=encoding UTF-8
 
 =head1 NAME
 
-App::Oozie::XML - XML Handler.
+App::Oozie::XML
+
+=head1 VERSION
+
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -487,6 +489,12 @@ App::Oozie::XML - XML Handler.
 
 Oozie XML spec Handler.
 
+=for Pod::Coverage BUILD
+
+=head1 NAME
+
+App::Oozie::XML - XML Handler.
+
 =head1 Methods
 
 =head2 is_foreign_prefix
@@ -519,5 +527,25 @@ Oozie XML spec Handler.
 
 L<App::Oozie>.
 
-=cut
+=head1 AUTHORS
 
+=over 4
+
+=item *
+
+David Morel
+
+=item *
+
+Burak Gursoy
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Booking.com.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
